@@ -4,20 +4,13 @@ from typing import List, Dict
 from jose import jwt
 import asyncio
 from delphai_utils.logging import logging
+from delphai_utils.config import get_config
 
 public_keys = {}
 
 # endpoint for getting all enabled JWKs
-base = 'https://auth.delphai'
-base_urls = {
-  'development': f'{base}.black',
-  'review': f'{base}.pink',
-  'staging': f'{base}.blue',
-  'green': f'{base}.green',
-  'live': f'{base}.live',
-}
-base_url = base_urls[os.environ.get("DELPHAI_ENVIRONMENT")]
-url = f'{base_url}/auth/relms/delphai/protocol/openid-connect/certs'
+base_url = get_config('keycloak.base_url') or 'https://auth.delphai.red'
+url = f'{base_url}/auth/realms/delphai/protocol/openid-connect/certs'
 
 
 async def decode_token(access_token: str) -> str:
